import 'dart:convert';
import 'package:http/http.dart' as http;
import 'package:flutter/foundation.dart';
import 'package:miapp_flutter/environments/archivo.dart';
import 'package:miapp_flutter/src/models/CategoriaModel.dart';

class CategoryApi {
  final String apiUrl = 'categoria'; // Asegúrate de que esta URL sea correcta

  Future<Map<String, dynamic>> getCategories() async {
    String url = '${apiApp}/$apiUrl?offset=0&max=100';
    if (kDebugMode) {
      print('Url -> $url');
    }
    try {
      final response = await http.get(Uri.parse(url));

      if (response.statusCode == 200) {
        return {
          'statusCode': response.statusCode,
          'body': response.body,
        };
      } else {
        return {
          'statusCode': response.statusCode,
          'body': 'Error: ${response.reasonPhrase}',
        };
      }
    } catch (e) {
      return {
        'statusCode': 501,
        'body': 'Error: $e',
      };
    }
  }


  Future<Map<String, dynamic>> postCategory(CategoriaModel categoria) async {
    String url = '$apiApp/$apiUrl';
    if (kDebugMode) {
      print('Url -> $url');
    }

    try {
      final response = await http.post(
        Uri.parse(url),
        headers: {'Content-Type': 'application/json'},
        body: json.encode(categoria.toJson()),
      );

      print('Status code: ${response.statusCode}');
      print('Response body: ${response.body}');

      return {
        "statusCode": response.statusCode,
        "body": response.body,
      };
    } catch (e) {
      return {
        "statusCode": 501,
        "body": '$e',
      };
    }
  }

}
