import 'dart:convert';

class ArticleModel {
  final int id;
  final String clave;
  final String nombre;
  final int categoriaId;
  final List<Price> precios;
  final bool activo;

  ArticleModel({
    required this.id,
    required this.clave,
    required this.nombre,
    required this.categoriaId,
    required this.precios,
    required this.activo,
  });

  factory ArticleModel.fromJson(Map<String, dynamic> json) {
    var list = json['precios'] as List;
    List<Price> preciosList = list.map((i) => Price.fromJson(i)).toList();

    return ArticleModel(
      id: json['id'],
      clave: json['clave'],
      nombre: json['nombre'],
      categoriaId: json['categoria']['id'],
      precios: preciosList,
      activo: json['activo'],
    );
  }

  static List<ArticleModel> fromJsonArray(List<dynamic> jsonArray) {
    return jsonArray.map((json) => ArticleModel.fromJson(json)).toList();
  }

  Map<String, dynamic> toJson() {
    return {
      'id': id,
      'clave': clave,
      'nombre': nombre,
      'categoria': {'id': categoriaId},
      'precios': precios.map((p) => p.toJson()).toList(),
      'activo': activo,
    };
  }

  static List<Map<String, dynamic>> toJsonArray(List<ArticleModel> articles) {
    return articles.map((article) => article.toJson()).toList();
  }
}

class Price {
  final int id;
  final double precio;

  Price({
    required this.id,
    required this.precio,
  });

  factory Price.fromJson(Map<String, dynamic> json) {
    return Price(
      id: json['id'],
      precio: json['precio'].toDouble(),
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'id': id,
      'precio': precio,
    };
  }
}
